@@ -24,12 +24,6 @@
 #' @noRd
 .MCCI <- function(object,
                   alpha = NULL) {
-  stopifnot(
-    inherits(
-      object,
-      "semmcci"
-    )
-  )
   thetahatstar <- object$thetahatstar
   thetahat <- object$thetahat
   if (is.null(alpha)) {
@@ -58,5 +52,5 @@
   if (!is.null(varnames)) {
     rownames(ci) <- varnames
   }
-  return(ci)
+  ci
 }
